import javax.swing.*;
import java.util.*;
import java.io.*;
import java.awt.Container;
import java.awt.BorderLayout;
import java.awt.Image;
import java.awt.event.*;

/**
 * Class that can play movies from multiple frames
 * @author Barb Ericson
 */
public class MoviePlayer
{
  
  ///////////////// fields ///////////////////////////
 
  private JFrame frame = new JFrame("Movie Player");
  private JLabel frameLabel = new JLabel("No images yet!");
  private JLabel pictureLabel = null;
  private int currIndex = 0;
  private List pictureList = null;
  private int framesPerSec = 30;
  
  //////////////////// constructors ////////////////////
  
  /**
   * Constructor that takes a title for the window
   * @param pictureList the list of pictures to show
   */
  public MoviePlayer(List pictureList)
  {
    this.pictureList = pictureList;
    init();
  }
  
  /**
   * Constructor that takes a directory and shows a movie
   * from it
   * @param directory the directory with the frames
   */
  public MoviePlayer(String directory)
  {
    Picture p = null;
    pictureList = new ArrayList();
    
    // get the list of files in the directory
    File dirObj = new File(directory);
    String[] fileArray = dirObj.list();
    
    // loop through the files
    for (int i = 0; i < fileArray.length; i++)
    {
      if (fileArray[i].indexOf(".jpg") >= 0)
      {
        p = new Picture(directory + fileArray[i]);
        pictureList.add(p);
      }
    }
    
    init();
  }
  
  /////////////////////// methods ////////////////////////////
  
  /**
   * Method to show the next image
   */
  public void showNext()
  {
    frame.setVisible(true);
    currIndex++;
    if (currIndex == pictureList.size())
      currIndex = 0;
    Picture p = (Picture) pictureList.get(currIndex);
    ImageIcon icon = new ImageIcon(p.getImage());
    pictureLabel.setIcon(icon);
    frameLabel.setText("Frame Number " + currIndex);
    frame.repaint();
  }
  
  /**
   * Method to show the previous image
   */
  public void showPrevious()
  {
    frame.setVisible(true);
    currIndex--;
    if (currIndex <  0)
      currIndex = pictureList.size() - 1;
    Picture p = (Picture) pictureList.get(currIndex);
    ImageIcon icon = new ImageIcon(p.getImage());
    pictureLabel.setIcon(icon);
    frameLabel.setText("Frame Number " + currIndex);
    frame.repaint();
  }
  
  /**
   * Method to play the movie from the beginning
   */
  public void playMovie()
  {
    playMovie(this.framesPerSec);
  }  
  
   /**
   * Method to play the movie from the beginning
   * @param framesPerSecond the number of frames to show
   * per second
   */
  public void playMovie(int framesPerSecond)
  {
    int sleepTime = 1000 / framesPerSecond;
    Picture p = null;
    ImageIcon icon = null;
    currIndex = 0;
    frame.setVisible(true);
    for (;currIndex < pictureList.size(); currIndex++)
    {
        p = (Picture) pictureList.get(currIndex);
        icon = new ImageIcon(p.getImage());
        pictureLabel.setIcon(icon);
        frameLabel.setText("Frame Number " + currIndex);
        frame.repaint();
        try {
          Thread.sleep(sleepTime);
        } catch (Exception ex) {
        }
    }
    currIndex = pictureList.size() - 1;
  }  
  
  /**
   * Method to add a picture to the movie
   * @param picture the picture to add
   */
  public void addPicture(Picture picture)
  {
    pictureList.add(picture);
    showNext();
  }
  
  /**
   * Method to set up the gui
   */
  private void init()
  {
    Picture p = (Picture) pictureList.get(0);
    ImageIcon icon = new ImageIcon(p.getImage());
    pictureLabel = new JLabel(icon);
    Container container = frame.getContentPane();
    container.setLayout(new BorderLayout());
    JPanel buttonPanel = new JPanel();
    
    // add the picture label to the center
    container.add(pictureLabel,BorderLayout.CENTER);
    
    // add the frame label to the north
    JPanel labelPanel = new JPanel();
    labelPanel.add(frameLabel);
    container.add(labelPanel,BorderLayout.NORTH);
    
    // add the button panel to the south
    container.add(new ButtonPanel(this),BorderLayout.SOUTH);
      
    // set the size of the frame
    frame.pack();
  }
  
  /**
   * Method to set the visibility of the frame
   * @param flag the visibility of the frame
   */
  public void setVisible(boolean flag)
  {
    frame.setVisible(flag);
  }
  
  public static void main(String[] args)
  {
    MoviePlayer moviePlayer = new MoviePlayer("c:/intro-prog-java/mediasources/fish/");
    moviePlayer.playMovie(16);
  }
  
}
  